/*
 * gsampler-channel.h
 * Copyright (C) Lilian Monchalin 2011 <isaya07@users.sf.net>
 *	 
 * gsampler is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * gsampler is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _GSAMPLER_CHANNEL_H_
#define _GSAMPLER_CHANNEL_H_

#include <gtk/gtk.h>
#include "gsampler-instrument.h"
#include "gsampler-client-channel.h"

G_BEGIN_DECLS

#define GSAMPLER_TYPE_CHANNEL (gsampler_channel_get_type ())
#define GSAMPLER_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GSAMPLER_TYPE_CHANNEL, GsamplerChannel))
#define GSAMPLER_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GSAMPLER_TYPE_CHANNEL, GsamplerChannelClass))
#define GSAMPLER_IS_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GSAMPLER_TYPE_CHANNEL))
#define GSAMPLER_IS_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GSAMPLER_TYPE_CHANNEL))
#define GSAMPLER_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GSAMPLER_TYPE_CHANNEL, GsamplerChannelClass))
#define GSAMPLER_CHANNEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSAMPLER_TYPE_CHANNEL, GsamplerChannelPrivate))

typedef struct _GsamplerChannel GsamplerChannel;
typedef struct _GsamplerChannelClass GsamplerChannelClass;
typedef struct _GsamplerChannelPrivate GsamplerChannelPrivate;

struct _GsamplerChannel {
	GtkFrame parent_instance;
	GsamplerChannelPrivate * priv;
};

struct _GsamplerChannelClass {
	GtkFrameClass parent_class;
};

struct _GsamplerChannelPrivate {
	GtkDrawingArea* draw_area;
	GsamplerInstrument* instrument;
	GtkBox* pref_box;
	GtkComboBox* midi_combo;
	GtkComboBox* audio_combo;
	GtkComboBox* chan_combo;
	GtkComboBox* map_combo;
	GtkComboBox* inst_combo;
	GtkComboBox* port_combo;
	GtkAdjustment* vol_adj;
	GtkToggleButton* solo_but;
	GtkToggleButton* mute_but;
	gchar* font;
	gchar* stream;
	gchar* voice;
	GsamplerChannelInfo *info;
	GtkWindow *chan_routing;
};

GType 					gsampler_channel_get_type (void) G_GNUC_CONST;
GsamplerChannel* 		gsampler_channel_new (void);

gboolean 				gsampler_channel_active (GsamplerChannel* self, gint id);
void 					gsampler_channel_update_voice_count (GsamplerChannel* self, gint val);
void 					gsampler_channel_update_stream_count (GsamplerChannel* self, gint val);
void					gsampler_channel_update_info (GsamplerChannel* self);
gint 					gsampler_channel_get_channel_id (GsamplerChannel* self);
GsamplerChannelInfo * 	gsampler_channel_get_info (GsamplerChannel* self);

G_END_DECLS

#endif /* _GSAMPLER_CHANNEL_H_ */