/*
 * gsampler-client-midimap.h
 * Copyright (C) Lilian Monchalin 2011 <isaya07@users.sf.net>
 * 
 * gsampler is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * gsampler is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _GSAMPLER_CLIENT_MIDIMAP_H_
#define _GSAMPLER_CLIENT_MIDIMAP_H_

#include "gsampler-client.h"

#define GSAMPLER_TYPE_MIDI_MAP_INFO (gsampler_midi_map_info_get_type ())
typedef struct _GsamplerMidiMapInfo GsamplerMidiMapInfo;
struct _GsamplerMidiMapInfo {
	gchar* name;
	gboolean defaut;
};

#define GSAMPLER_TYPE_MIDI_INST_INFO (gsampler_midi_inst_info_get_type ())
typedef struct _GsamplerMidiInstInfo GsamplerMidiInstInfo;
struct _GsamplerMidiInstInfo {
	gchar* name;
	gchar* engine;
	gchar* file;
	gint inst_nb;
	gchar* inst_name;
	gchar* load_mode;
	gdouble vol;
};

GType gsampler_midi_map_info_get_type (void) G_GNUC_CONST;
GsamplerMidiMapInfo* gsampler_midi_map_info_dup (const GsamplerMidiMapInfo* self);
void gsampler_midi_map_info_free (GsamplerMidiMapInfo* self);
void gsampler_midi_map_info_copy (const GsamplerMidiMapInfo* self, GsamplerMidiMapInfo* dest);
void gsampler_midi_map_info_destroy (GsamplerMidiMapInfo* self);

GType gsampler_midi_inst_info_get_type (void) G_GNUC_CONST;
GsamplerMidiInstInfo* gsampler_midi_inst_info_dup (const GsamplerMidiInstInfo* self);
void gsampler_midi_inst_info_free (GsamplerMidiInstInfo* self);
void gsampler_midi_inst_info_copy (const GsamplerMidiInstInfo* self, GsamplerMidiInstInfo* dest);
void gsampler_midi_inst_info_destroy (GsamplerMidiInstInfo* self);

gchar** 	gsampler_client_get_available_midi_instrument_map (GsamplerClient* self);
GSList * 	gsampler_client_get_available_midi_instruments (GsamplerClient* self, gint map);
gint 		gsampler_client_create_midi_instrument_map (GsamplerClient* self, const gchar* name);
gboolean 	gsampler_client_delete_midi_instrument_map (GsamplerClient* self, gint id);
gboolean 	gsampler_client_delete_all_midi_instrument_map (GsamplerClient* self);
gint 		gsampler_client_get_midi_instrument_map (GsamplerClient* self);
GsamplerMidiMapInfo * gsampler_client_get_midi_instrument_map_info (GsamplerClient* self, gint id);
gboolean 	gsampler_client_set_midi_instrument_map_name (GsamplerClient* self, gint id, const gchar* name);
gboolean 	gsampler_client_map_midi_instrument (GsamplerClient* self, gint map, gdouble bank, gint prog, const gchar* engine, const gchar* file, gint instrument, gdouble vol, const gchar* load_mode, const gchar* name);
gchar* 		gsampler_client_get_midi_instruments (GsamplerClient* self, gint map);
gboolean 	gsampler_client_unmap_midi_instrument (GsamplerClient* self, gint map, gint bank, gint prog);
GsamplerMidiInstInfo* gsampler_client_get_midi_instruments_info (GsamplerClient* self, gint map, gint bank, gint prog);
gboolean 	gsampler_client_clear_midi_instrument_map (GsamplerClient* self, gint id);

#endif /* _GSAMPLER_CLIENT_MIDIMAP_H_ */